mptcp.lists.linux.dev archive mirror
 help / color / mirror / Atom feed
* [PATCH mptcp-next] Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels"
@ 2022-06-27 21:44 Mat Martineau
  2022-06-27 23:11 ` Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels": Tests Results MPTCP CI
  2022-06-28  9:42 ` [PATCH mptcp-next] Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels" Matthieu Baerts
  0 siblings, 2 replies; 5+ messages in thread
From: Mat Martineau @ 2022-06-27 21:44 UTC (permalink / raw)
  To: mptcp; +Cc: Mat Martineau, pabeni

kbuild is still seeing intermittent failures in the simult_flows.sh
test. It uses a kernel config without kmemleak, but with other
performance-affecting debug options like lockdep and kasan.

Example failures:
kernel-selftests.net/mptcp.simult_flows.sh.unbalanced_bwidth_with_unbalanced_delay_transfer_slower_than_expected!_runtime_4339_ms_expected_4005_ms_max_4005.fail
kernel-selftests.net/mptcp.simult_flows.sh.unbalanced_bwidth_transfer_slower_than_expected!_runtime_4285_ms_expected_4005_ms_max_4005.fail
kernel-selftests.net/mptcp.simult_flows.sh.unbalanced_bwidth_transfer_slower_than_expected!_runtime_4346_ms_expected_4005_ms_max_4005.fail

Adjust the debug detection to loosen the simult_flows timing constraints
if either kmemleak or lockdep are configured.

Signed-off-by: Mat Martineau <mathew.j.martineau@linux.intel.com>
---
 tools/testing/selftests/net/mptcp/simult_flows.sh | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/tools/testing/selftests/net/mptcp/simult_flows.sh b/tools/testing/selftests/net/mptcp/simult_flows.sh
index e266b26a4274..fa4f0bf55049 100755
--- a/tools/testing/selftests/net/mptcp/simult_flows.sh
+++ b/tools/testing/selftests/net/mptcp/simult_flows.sh
@@ -110,9 +110,10 @@ setup()
 	# debug build can slow down measurably the test program
 	# we use quite tight time limit on the run-time, to ensure
 	# maximum B/W usage.
-	# Use the kmemleak file presence as a rough estimate for this being
-	# a debug kernel and increase the maximum run-time accordingly
-	[ -f /sys/kernel/debug/kmemleak ] && slack=$((slack+200))
+	# Use the kmemleak or lockdep file presence as a rough estimate
+	# for this being a debug kernel and increase the maximum
+	# run-time accordingly
+	[ -f /sys/kernel/debug/kmemleak -o -f /proc/lockdep ] && slack=$((slack+200))
 }
 
 # $1: ns, $2: port
-- 
2.36.1


^ permalink raw reply related	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2022-06-29  8:32 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-06-27 21:44 [PATCH mptcp-next] Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels" Mat Martineau
2022-06-27 23:11 ` Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels": Tests Results MPTCP CI
2022-06-28  9:42 ` [PATCH mptcp-next] Squash-to: "selftests: mptcp: tweak simult_flows for debug kernels" Matthieu Baerts
2022-06-28 17:55   ` Mat Martineau
2022-06-29  8:32     ` Matthieu Baerts

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).